# Changes to PostCSS Place Properties

### 10.0.0

_August 3, 2024_

- Updated: Support for Node v18+ (major).

[Full CHANGELOG](https://github.com/csstools/postcss-plugins/tree/main/plugins/postcss-place/CHANGELOG.md)
